==> r-mail-1.0.0.zip: r-mail-1.0.0/gestion_messages/copier_message.php <==
<?

session_start ();

$serveur="{".$serveur_mail.":$port_connexion"."}$nom_boite";

$connect_imap=@imap_open($serveur,"$login","$password")
or die ('impossible de se connecter au serveur');

//On ralise des suites logiques pour dterminer les intervalles
//demandes par imap_mail_copy

$suite_logique=array();
$stock=array();

if (count ($z)==0) {
exit ("<center>Merci de cocher les messages  copier</center>".
"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
}

foreach ($z as $suite) {
	
	if ($suite!=1 && count ($stock)!=0 && max ($stock)+1==$suite && end($z)!=$suite) {
		array_push ($suite_logique, $suite-1, $suite);
		array_shift ($stock);
	} else {
		array_push ($stock, $suite);
		if (!isset ($fait) && count ($suite_logique)!=0) {
			$fait=1;
			$boom=implode ("," , $suite_logique);
			if (imap_mail_copy ($connect_imap, "$boom", $sel_boite)!=true) {
			exit ("<center>L'intervalle de copies n'a pas fonctionne</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_splice ($suite_logique, 0);
		} elseif (count ($stock) >1) {
			if (imap_mail_copy ($connect_imap, "$stock[0]", $sel_boite)!=true) {
			exit ("<center>La copie n'a pas fonctionne</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_shift ($stock);
			unset ($fait);
		} else {
			unset ($fait);
		}
	}
	
	if (end($z)==$suite) {
		if (count ($suite_logique)!=0) {
		$boom=implode ("," , $suite_logique);
			if (imap_mail_copy ($connect_imap, "$boom", $sel_boite)!=true) {
			exit ("<center>La copie du dernier intervalle n'a pas fonctionne</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
		array_splice ($suite_logique, 0);
		}
	if (count ($stock)!=0) {
		$boom=implode ("," , $stock);
			if (imap_mail_copy ($connect_imap, "$boom", $sel_boite)!=true) {
			exit ("<center>La dernire copie n'a pas fonctionne</center>\n".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>\n</td></tr>\n</table>\n");
			}
		array_splice ($stock, 0);
		}
	}
	
}

imap_close ($connect_imap);

?>

==> r-mail-1.0.2.zip: r-mail.1.0.2/gestion_messages/copier_message.php <==
<?

include 'langage.php';

$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}".$_POST ["nom_boite"];

$connect_imap=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
or die ($page_copier_message[$_SESSION ["lang"]][0]);

//On ralise des suites logiques pour dterminer les intervalles
//demandes par imap_mail_copy

$suite_logique=array();
$stock=array();

if (count ($_POST ["z"])==0) {
exit ("<center>".$page_copier_message[$_SESSION ["lang"]][1]."</center>".
"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
}

foreach ($_POST ["z"] as $suite) {
	
	if ($suite!=1 && count ($stock)!=0 && max ($stock)+1==$suite && end($_POST ["z"])!=$suite) {
		array_push ($suite_logique, $suite-1, $suite);
		array_shift ($stock);
	} else {
		array_push ($stock, $suite);
		if (!isset ($fait) && count ($suite_logique)!=0) {
			$fait=1;
			$boom=implode ("," , $suite_logique);
			if (imap_mail_copy ($connect_imap, "$boom", $_POST ["sel_boite"])!=true) {
			exit ("<center>".$page_copier_message[$_SESSION ["lang"]][2]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_splice ($suite_logique, 0);
		} elseif (count ($stock) >1) {
			if (imap_mail_copy ($connect_imap, "$stock[0]", $_POST ["sel_boite"])!=true) {
			exit ("<center>".$page_copier_message[$_SESSION ["lang"]][3]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
			array_shift ($stock);
			unset ($fait);
		} else {
			unset ($fait);
		}
	}
	
	if (end($_POST ["z"])==$suite) {
		if (count ($suite_logique)!=0) {
		$boom=implode ("," , $suite_logique);
			if (imap_mail_copy ($connect_imap, "$boom", $_POST ["sel_boite"])!=true) {
			exit ("<center>".$page_copier_message[$_SESSION ["lang"]][4]."</center>".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
		array_splice ($suite_logique, 0);
		}
	if (count ($stock)!=0) {
		$boom=implode ("," , $stock);
			if (imap_mail_copy ($connect_imap, "$boom", $_POST ["sel_boite"])!=true) {
			exit ("<center>".$page_copier_message[$_SESSION ["lang"]][5]."</center>\n".
			"<table border=0 width=100% bgcolor=\"#1FCBCB\" cellspacing=0>\n<tr><td>\n".
			"</td></tr>\n</table>\n<font size=1>&#160;</font>\n<table border=0 width=100% cellspacing=0>\n".
			"<tr><td bgcolor=\"#1FCBCB\">\n<br>\n</tr>\n</table>\n".
			"<br>\n<table border=0 width=100% cellspacing=0>\n<tr><td align=middle bgcolor=\"#1FCBCB\">\n".
			"<font size=5><b><u>R-MAIL</u></b></font>\n</td></tr>\n</table>\n");
			}
		array_splice ($stock, 0);
		}
	}
	
}

imap_close ($connect_imap);

?>
